
.. _ref-getting-started:

Getting started
###############


.. grid:: 1 2 3 3
    :gutter: 1 2 3 3
    :padding: 1 2 3 3

    .. grid-item-card:: How to install :fa:`person-running`
        :link: getting-started/installation
        :link-type: doc

        Learn how to download and install the theme.

.. toctree::
   :maxdepth: 2
   :hidden:

   getting-started/installation
